import setuptools

setuptools.setup(
	name = "BannerRifael",
	version = "0.1",
	author = "Rifael",
	author_email = "sitorusrifael@gamil.com",
	description = "Make Your Cool Banner",
	packages = setuptools.find_packages(),
	
	classifiers = [
		"Programming Language :: Python :: 3",
		"License :: OSI Approved :: MIT License",
		"Operating System :: OS Independent",
	
	
	],
	




)